@@ -18,6 +18,14 @@ use Try::Tiny;
 
 use Types::Standard qw/Any Int Str/;
 
+has ambiguous =>
+(
+	default  => sub{return 0},
+	is       => 'rw',
+	isa      => Int,
+	required => 0,
+);
+
 has bnf =>
 (
 	default  => sub{return ''},
@@ -98,7 +106,7 @@ has warning_str =>
 	required => 0,
 );
 
-our $VERSION = '1.03';
+our $VERSION = '1.05';
 
 # ------------------------------------------------
 
@@ -127,6 +135,8 @@ sub append
 
 	for my $param (qw/text uid/)
 	{
+		# The \n stops Perl printing the line number.
+
 		die "Method append() takes a hash with these keys: text, uid\n" if (! defined($opts{$param}) );
 	}
 
@@ -199,6 +209,8 @@ sub find
 {
 	my($self, $target) = @_;
 
+	# The \n stops Perl printing the line number.
+
 	die "Method find() takes a defined value as the parameter\n" if (! defined $target);
 
 	my(@found);
@@ -229,6 +241,8 @@ sub get
 
 	if (! defined($wanted_uid) || ($wanted_uid < 1) || ($wanted_uid > $self -> uid) )
 	{
+		# The \n stops Perl printing the line number.
+
 		die "Method get() takes a uid parameter in the range 1 .. $max_uid\n";
 	}
 
@@ -304,16 +318,23 @@ sub parse
 		{
 			$result = 1;
 
-			my($message) = 'Error: Marpa parse failed. ';
+			if ($self -> ambiguous)
+			{
+				die "\n";
+			}
+			else
+			{
+				# The \n stops Perl printing the line number.
 
-			print $message, "\n" if ($self -> verbose);
-
-			die $message;
+				die "Error: Marpa parse failed.\n";
+			}
 		}
 	}
 	catch
 	{
-		die $_;
+		# The \n stops Perl printing the line number.
+
+		die "$_\n";
 	};
 
 	# Return 0 for success and 1 for failure.
@@ -330,6 +351,8 @@ sub prepend
 
 	for my $param (qw/text uid/)
 	{
+		# The \n stops Perl printing the line number.
+
 		die "Method append() takes a hash with these keys: text, uid\n" if (! defined($opts{$param}) );
 	}
 
@@ -411,6 +434,8 @@ sub _process
 		$lexeme	= $self -> recce -> literal($start, $span);
 		$pos	= $self -> recce -> lexeme_read($event_name);
 
+		# The \n stops Perl printing the line number.
+
 		die "Marpa lexeme_read($event_name) rejected lexeme '$lexeme'\n" if (! defined $pos);
 
 		$self -> _add_daughter($event_name, {text => $lexeme});
@@ -420,9 +445,15 @@ sub _process
 
 	if (my $status = $self -> recce -> ambiguous)
 	{
+		$self -> ambiguous(1);
+
 		my($terminals)	= $self -> recce -> terminals_expected;
-		$terminals		= ['(None)'] if ($#$terminals < 0);
-		$message		= "Marpa warning. Parse ambiguous. Status: $status. Terminals expected: " . join(', ', @$terminals);
+		$terminals		= ['(None)'] if ($#$terminals < 0); # Next line deliberately omits '.' after $status, so output lines up.
+		$message		= "Marpa error. Parse ambiguous. Status: ${status}Terminals expected: " . join(', ', @$terminals);
+
+		print "$message\n";
+
+		$message = ''; # To stop it being stored just below, and to stop it being printed again.
 	}
 	elsif ($self -> recce -> exhausted)
 	{
@@ -434,7 +465,7 @@ sub _process
 		}
 
 		# See https://metacpan.org/pod/distribution/Marpa-R2/pod/Exhaustion.pod#Exhaustion
-		# for why this code is exhaustion-loving.
+		# for why this code is exhaustion-loving. This is not an error. See docs for details.
 
 		$message = 'Marpa parse exhausted' if ($self -> verbose > 1);
 	}
@@ -443,14 +474,15 @@ sub _process
 	{
 		$self -> warning_str($message);
 
-		print $message, "\n" if ($self -> verbose);
+		print "$message\n" if ($self -> verbose);
 	}
 
 	$self -> print_raw_tree if ($self -> verbose);
 
 	# Return a defined value for success and undef for failure.
+	# Note: value() can return undef.
 
-	return $self -> recce -> value;
+	return $self -> ambiguous ? undef : $self -> recce -> value;
 
 } # End of _process.
 
@@ -493,6 +525,7 @@ sub reset
 {
 	my($self) = @_;
 
+	$self -> ambiguous(0);
 	$self -> tree(Tree -> new('Root') );
 	$self -> tree -> meta({text => 'Root', uid => 0});
 	$self -> current_node($self -> tree);
@@ -507,6 +540,8 @@ sub search
 {
 	my($self, $target) = @_;
 
+	# The \n stops Perl printing the line number.
+
 	die "Method search() takes a defined value as the parameter\n" if (! defined $target);
 
 	my($re) = $self -> _string2re($target);
@@ -538,6 +573,8 @@ sub set
 
 	for my $param (qw/text uid/)
 	{
+		# The \n stops Perl printing the line number.
+
 		die "Method set() takes a hash with these keys: text, uid\n" if (! defined($opts{$param}) );
 	}
 
@@ -573,11 +610,9 @@ sub _string2re
 	}
 	catch
 	{
-		my($message) = "Error: Perl cannot convert $raw_re into qr/.../ form";
+		# The \n stops Perl printing the line number with 'die'.
 
-		print $message, "\n" if ($self -> verbose);
-
-		die $message;
+		die "Error: Perl cannot convert $raw_re into qr/.../ form\n";
 	};
 
 	return $re;
@@ -652,7 +687,9 @@ sub _validate_event
 		{
 			#$self -> print_cooked_tree;
 
-			die "event_count: $event_count. " . $event_list;
+			# The \n stops Perl printing the line number.
+
+			die "event_count: $event_count. " . $event_list . "\n";
 		}
 	}
 
@@ -1295,11 +1332,19 @@ dealing with this issue.
 
 =head2 After calling parse(), warning_str() contains the string '... Parse ambiguous ...'
 
-This is almost certainly a error with the BNF, although of course it may be an error will an
+This is almost certainly an error with the BNF, although of course it may be an error with an
 exceptionally-badly formed regexp.
 
-Report it via L<https://rt.cpan.org/Public/Dist/Display.html?Name=Regexp-Parsertron>, and please
- include the regexp in the report. Thanx!
+See examples/ambiguous.pl and
+L<this email thread|https://www.nntp.perl.org/group/perl.perl5.porters/2018/07/msg251447.html>.
+
+See examples/commit.pl and
+L<this email thread|https://www.nntp.perl.org/group/perl.perl5.porters/2018/07/msg251463.html>.
+
+In such cases the code dies, as of V 1.04.
+
+Please report it via L<https://rt.cpan.org/Public/Dist/Display.html?Name=Regexp-Parsertron>, and
+include the regexp in the report. Thanx!
 
 =head2 Is this a (Marpa) exhaustion-hating or exhaustion-loving app?
 
@@ -1364,6 +1409,8 @@ benefit.
 
 =head1 References
 
+L<https://www.rexegg.com/regex-lookarounds.html>. Mastering Lookahead and Lookbehind.
+
 L<http://www.pcre.org/>. PCRE - Perl Compatible Regular Expressions.
 
 L<http://perldoc.perl.org/perlre.html>. This is the definitive document.
